'use client'

import { useEffect, useState } from 'react'
import { FiEdit2, FiTrash2, FiPlus, FiPackage } from 'react-icons/fi'
import DashboardLayout from '../../../components/layout/DashboardLayout'
import Link from 'next/link'
import { productService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import Image from 'next/image'

export default function ProductsPage() {
  const [products, setProducts] = useState([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState(false)
  const { user } = useUser()


  const fetchProducts = async () => {
    try {
      const response = await productService.index(user?.token || '')
      setProducts(response.data.products)
      setLoading(false)
    } catch (err) {
      setError(true)
      setLoading(false)
    }
  }
  useEffect(() => {
    if (user?.token) {
      fetchProducts()
    }
  }, [user?.token])

  const handleDelete = async (id: number) => {
    try {
      await productService.destroy(id.toString(), user?.token || '')
      fetchProducts()
    } catch (err) {
      console.error(err)
    }
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex flex-col sm:flex-row sm:items-center justify-between gap-4">
          <div>
            <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
              Ürün Listesi
            </h1>
            <p className="mt-1 text-sm text-slate-500 dark:text-slate-400">
              Tüm ürünleri görüntüle, düzenle ve yönet
            </p>
          </div>
          <Link
            href="/dashboard/products/add"
            className="inline-flex items-center gap-2 px-4 py-2.5 text-sm font-medium 
                     text-white bg-gradient-to-r from-fuchsia-500 to-purple-600 
                     rounded-xl hover:opacity-90 transition-all"
          >
            <FiPlus className="w-4 h-4" />
            Yeni Ürün
          </Link>
        </div>

        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg border border-slate-200/50 dark:border-slate-700/50">
          <div className="overflow-x-auto">
            <table className="w-full">
              <thead>
                <tr className="border-b border-slate-200/50 dark:border-slate-700/50">
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Ürün
                  </th>
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Fiyat
                  </th>
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200">
                    Kategori
                  </th>
                  <th className="text-left px-6 py-4 text-sm font-semibold text-slate-800 dark:text-slate-200 hidden sm:table-cell">
                    Oluşturulma Tarihi
                  </th>
                  <th className="px-6 py-4 text-right">
                    <span className="sr-only">Actions</span>
                  </th>
                </tr>
              </thead>
              <tbody>
                {Array.isArray(products) && products.map((product: any) => (
                  <tr
                    key={product.id}
                    className="border-b border-slate-200/50 dark:border-slate-700/50 last:border-0
                             hover:bg-slate-50/50 dark:hover:bg-slate-700/50 transition-colors"
                  >
                    <td className="px-6 py-4 whitespace-nowrap">
                      <div className="flex items-center gap-3">
                        <img
                          src={`${process.env.NEXT_PUBLIC_API_URL_STORAGE}/${product.image}`}
                          alt={product.name}
                          width={200}
                          height={150}
                          className="w-full h-24 object-cover rounded-lg mb-3"
                        />
                        <span className="text-sm font-medium text-slate-700 dark:text-slate-200">
                          {product.name}
                        </span>
                      </div>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap">
                      <span className="text-sm font-medium text-slate-700 dark:text-slate-200">
                        ₺{product.price}
                      </span>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap">
                      <span className="inline-flex items-center px-2.5 py-1 rounded-full text-xs font-medium
                                   bg-fuchsia-100/50 dark:bg-fuchsia-900/50 
                                   text-fuchsia-600 dark:text-fuchsia-400">
                        {product.category?.name || 'Kategorisiz'}
                      </span>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap hidden sm:table-cell">
                      <span className="text-sm text-slate-500 dark:text-slate-400">
                        {new Date(product.created_at).toLocaleDateString('tr-TR')}
                      </span>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap text-right">
                      <div className="flex items-center justify-end gap-2">
                        <Link
                          href={`/dashboard/products/edit/${product.id}`}
                          className="p-2 rounded-lg bg-slate-100/50 dark:bg-slate-700/50 
                                   text-slate-600 dark:text-slate-300 
                                   hover:bg-fuchsia-50 dark:hover:bg-slate-600/50 
                                   hover:text-fuchsia-500 transition-colors"
                        >
                          <FiEdit2 className="w-4 h-4" />
                        </Link>
                        <button
                          onClick={() => handleDelete(product.id)}
                          className="p-2 rounded-lg bg-slate-100/50 dark:bg-slate-700/50 
                                   text-slate-600 dark:text-slate-300 
                                   hover:bg-red-50 dark:hover:bg-red-900/10 
                                   hover:text-red-500 transition-colors"
                        >
                          <FiTrash2 className="w-4 h-4" />
                        </button>
                      </div>
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </DashboardLayout>
  )
} 